{% extends "base.html" %}

{% block content %}
<h1>500 An unexpected error has occurred.</h1>
<p>Please consider opening an Issue on GitHub if this problem persists</p>
<p><a href="{{ url_for('main.index') }}">Back</a></p>
{% endblock %}
