{% extends "base.html" %}

{% block content %}
<h1>401 Unauthorized Access denied!</h1>
<p>How did you achieve this on a local web app?</p>
<p><a href="{{ url_for('main.index') }}">Back</a></p>
{% endblock %}
