{% extends "base.html" %}

{% block content %}
<h1>400 Bad Request</h1>
<p>Please open an Issue on GitHub if this problem persists</p>
<p><a href="{{ url_for('main.index') }}">Back</a></p>
{% endblock %}
